Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(566)

Unified Diff: runtime/include/dart_api.h

Issue 196443009: - First step in refactoring ports with the goal of moving (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/lib/isolate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
===================================================================
--- runtime/include/dart_api.h (revision 34429)
+++ runtime/include/dart_api.h (working copy)
@@ -1089,8 +1089,13 @@
*/
DART_EXPORT Dart_Handle Dart_NewSendPort(Dart_Port port_id);
+
+DART_EXPORT Dart_Handle Dart_PortGetId(Dart_Handle port, Dart_Port* port_id);
+
/**
* Gets the ReceivePort for the provided port id, creating it if necessary.
*
* Note that there is at most one ReceivePort for a given port id.
*/
@@ -1089,8 +1089,13 @@
/**
- * Gets the ReceivePort for the provided port id, creating it if necessary.
+ * Gets the ReceivePort for the provided port id.
+ * Returns Dart_Null if a port with the provided port id is not associated with
+ * the current isolate.
*
* Note that there is at most one ReceivePort for a given port id.
« no previous file with comments | « no previous file | runtime/lib/isolate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698